@@ -19,14 +19,17 @@ from goodbyecaptcha.util import get_random_proxy
 
 
 class Solver(Base):
-    def __init__(self, pageurl, loop=None, proxy=None, proxy_auth=None, options=None, lang='en-US', **kwargs):
+    def __init__(self, pageurl, loop=None, proxy=None, proxy_auth=None, options=None, lang='en-US', chromePath=None,
+                 **kwargs):
         self.url = pageurl
         self.loop = loop or util.get_event_loop()
         self.proxy = proxy
         self.proxy_auth = proxy_auth
         self.options = merge_dict({} if options is None else options, kwargs)
+        self.chromePath = chromePath
 
-        super(Solver, self).__init__(loop=loop, proxy=proxy, proxy_auth=proxy_auth, language=lang, options=options)
+        super(Solver, self).__init__(loop=loop, proxy=proxy, proxy_auth=proxy_auth, language=lang, options=options,
+                                     chromePath=chromePath)
 
     async def start(self):
         """Begin solving"""
@@ -102,12 +105,12 @@ class Solver(Base):
         if self.method == 'images':
             self.log('Using Image Solver')
             self.image = SolveImage(page=self.page, image_frame=self.image_frame, loop=self.loop, proxy=proxy,
-                                    proxy_auth=self.proxy_auth, options=self.options)
+                                    proxy_auth=self.proxy_auth, options=self.options, chromePath=self.chromePath)
             solve = self.image.solve_by_image
         else:
             self.log('Using Audio Solver')
             self.audio = SolveAudio(page=self.page, image_frame=self.image_frame, loop=self.loop, proxy=proxy,
-                                    proxy_auth=self.proxy_auth, options=self.options)
+                                    proxy_auth=self.proxy_auth, options=self.options, chromePath=self.chromePath)
             solve = self.audio.solve_by_audio
 
         try:
